@@ -37,7 +37,12 @@
 #'    tip_coef(confounder_outcome_effect = 2.5)
 #'}
 #' @export
-tip_coef <- function(effect_observed, exposure_confounder_effect = NULL, confounder_outcome_effect = NULL, verbose = TRUE) {
+tip_coef <- function(effect_observed, exposure_confounder_effect = NULL, confounder_outcome_effect = NULL, verbose = getOption("tipr.verbose", TRUE)) {
+  check_arguments(
+    "tip_coef()",
+    exposure_confounder_effect,
+    confounder_outcome_effect
+  )
 
   o <- purrr::map(
     effect_observed,
@@ -72,11 +77,11 @@ tip_coef_one <- function(b, exposure_confounder_effect, confounder_outcome_effec
         confounder_outcome_effects <- confounder_outcome_effect
       }
 
-      warning_glue(
-        "The observed effect {b} would not tip with the unmeasured confounder given:",
-        "\n  * `exposure_confounder_effect`: {exposure_confounder_effects}",
-        "\n  * `confounder_outcome_effect`: {confounder_outcome_effects}\n\n"
-      )
+      warning_cli(c(
+        "!" = "The observed effect {b} would not tip with the unmeasured confounder given:",
+        "*" = "`exposure_confounder_effect`: {exposure_confounder_effects}",
+        "*" = "`confounder_outcome_effect`: {confounder_outcome_effects}\n\n"
+      ))
       n_unmeasured_confounders <- max(0, n_unmeasured_confounders)
     }
     too_small <-
@@ -87,11 +92,11 @@ tip_coef_one <- function(b, exposure_confounder_effect, confounder_outcome_effec
         ifelse(length(confounder_outcome_effect) > 1,
                confounder_outcome_effect[too_small],
                confounder_outcome_effect)
-      warning_glue(
-        "The observed effect {b} would tip with < 1 of the given unmeasured confounders:",
-        "\n  * `exposure_confounder_effect`: {exposure_confounder_effects}",
-        "\n  * `confounder_outcome_effect`: {confounder_outcome_effects}\n\n"
-      )
+      warning_cli(c(
+        "!" = "The observed effect {b} would tip with < 1 of the given unmeasured confounders:",
+        "*" = "`exposure_confounder_effect`: {exposure_confounder_effects}",
+        "*" = "`confounder_outcome_effect`: {confounder_outcome_effects}\n\n"
+      ))
     }
   }
   o <- tibble::tibble(
@@ -103,53 +108,53 @@ tip_coef_one <- function(b, exposure_confounder_effect, confounder_outcome_effec
   if (verbose) {
     if (all(o$n_unmeasured_confounders == 0)) {
       o_notip <- o[o$n_unmeasured_confounders == 0,]
-      message_glue(
-        "The observed effect ({round(o_notip$effect_observed, 2)}) ",
-        "cannot be tipped by an unmeasured confounder\nwith the ",
-        "following specifications:",
-        "\n  * estimated difference in scaled means between the ",
-        "unmeasured confounder\n     in the exposed population and ",
-        "unexposed population: {round(o_notip$exposure_confounder_effect, 2)}",
-        "\n  * estimated relationship between the unmeasured confounder and the ",
-        "outcome: {round(o_notip$confounder_outcome_effect, 2)}\n\n"
-      )
+      message_cli(c(
+        "i" = "The observed effect ({round(o_notip$effect_observed, 2)}) \\
+        cannot be tipped by an unmeasured confounder with the \\
+        following specifications:",
+        "*" = "estimated difference in scaled means between the \\
+        unmeasured confounder in the exposed population and \\
+        unexposed population: {round(o_notip$exposure_confounder_effect, 2)}",
+        "*" = "estimated relationship between the unmeasured confounder and \\
+        the outcome: {round(o_notip$confounder_outcome_effect, 2)}"
+      ))
     } else if (any(o$n_unmeasured_confounders == 0)) {
       o_notip <- o[o$n_unmeasured_confounders == 0,]
-      message_glue(
-        "The observed effect ({round(o_notip$effect_observed, 2)}) ",
-        "cannot be tipped by an unmeasured confounder\nwith the ",
-        "following specifications:",
-        "\n  * estimated difference in scaled means between the ",
-        "unmeasured confounder\n     in the exposed population and ",
-        "unexposed population: {round(o_notip$exposure_confounder_effect, 2)}",
-        "\n  * estimated relationship between the unmeasured confounder and the ",
-        "outcome: {round(o_notip$confounder_outcome_effect, 2)}\n\n"
-      )
+      message_cli(c(
+        "i" = "The observed effect ({round(o_notip$effect_observed, 2)}) \\
+        cannot be tipped by an unmeasured confounder with the \\
+        following specifications:",
+        "*" = "estimated difference in scaled means between the \\
+        unmeasured confounder in the exposed population and \\
+        unexposed population: {round(o_notip$exposure_confounder_effect, 2)}",
+        "*" = "estimated relationship between the unmeasured confounder and \\
+        the outcome: {round(o_notip$confounder_outcome_effect, 2)}"
+      ))
 
       o_tip <- o[o$n_unmeasured_confounders != 0,]
-      message_glue(
-        "The observed effect ({round(o_tip$effect_observed, 2)}) WOULD ",
-        "be tipped by {round(o$n_unmeasured_confounders)} ",
-        "unmeasured confounder{ifelse(o_tip$n_unmeasured_confounders > 1, 's', '')}\n",
-        "with the following specifications:",
-        "\n  * estimated difference in scaled means between the ",
-        "unmeasured confounder\n    in the exposed population and ",
-        "unexposed population: {round(o_tip$exposure_confounder_effect, 2)}",
-        "\n  * estimated relationship between the unmeasured confounder and the ",
-        "outcome: {round(o_tip$confounder_outcome_effect, 2)}\n\n"
-      )
+      message_cli(c(
+        "i" = "The observed effect ({round(o_tip$effect_observed, 2)}) WOULD \\
+        be tipped by {round(o$n_unmeasured_confounders)} \\
+        unmeasured confounder{ifelse(o_tip$n_unmeasured_confounders > 1, 's', '')}\n \\
+        with the following specifications:",
+        "*" = "estimated difference in scaled means between the \\
+        unmeasured confounder in the exposed population and \\
+        unexposed population: {round(o_tip$exposure_confounder_effect, 2)}",
+        "*" = "estimated relationship between the unmeasured confounder and \\
+        the outcome: {round(o_tip$confounder_outcome_effect, 2)}"
+      ))
     } else {
-      message_glue(
-        "The observed effect ({round(o$effect_observed, 2)}) WOULD ",
-        "be tipped by {round(o$n_unmeasured_confounders)} ",
-        "unmeasured confounder{ifelse(o$n_unmeasured_confounders > 1, 's', '')}\n",
-        "with the following specifications:",
-        "\n  * estimated difference in scaled means between the ",
-        "unmeasured confounder\n    in the exposed population and ",
-        "unexposed population: {round(o$exposure_confounder_effect, 2)}",
-        "\n  * estimated relationship between the unmeasured confounder and the ",
-        "outcome: {round(o$confounder_outcome_effect, 2)}\n\n"
-      )
+      message_cli(c(
+        "i" = "The observed effect ({round(o$effect_observed, 2)}) WOULD \\
+        be tipped by {round(o$n_unmeasured_confounders)} \\
+        unmeasured confounder{ifelse(o$n_unmeasured_confounders > 1, 's', '')}\n \\
+        with the following specifications:",
+        "*" = "estimated difference in scaled means between the \\
+        unmeasured confounder\n    in the exposed population and \\
+        unexposed population: {round(o$exposure_confounder_effect, 2)}",
+        "*" = "estimated relationship between the unmeasured confounder \\
+        and the outcome: {round(o$confounder_outcome_effect, 2)}"
+      ))
     }
   }
   o
