@@ -39,7 +39,6 @@ test_that("get_limiting_bound() gives correct bound", {
 })
 
 test_that("tip_gamma() errors when necessary", {
-  expect_error(tip_gamma(), "Please input at least 2 of the following")
   expect_error(
     tip_gamma(p0 = -1, p1 = 1),
     "The prevalences entered must be between 0 and 1"
@@ -56,6 +55,6 @@ test_that("tip_gamma() returns correct result", {
   expect_identical(tip_gamma(p0 = 1, p1 = 0, b = 1.2), 1 / 1.2)
   expect_error(
     tip_gamma(p0 = .5, p1 = .2, b = 5),
-    "There does not exist an unmeasured confounder"
+    "there does not exist an unmeasured"
   )
 })
